@@ -3,7 +3,7 @@ use warnings;
 
 package Data::Handle::Exception;
 BEGIN {
-  $Data::Handle::Exception::VERSION = '0.01011500';
+  $Data::Handle::Exception::VERSION = '0.01011501';
 }
 
 # ABSTRACT: Super-light Weight Dependency Free Exception base.
@@ -34,6 +34,17 @@ sub throw {
   my @stack      = ();
   my @stacklines = ();
 
+  my $callerinfo;
+
+  if ( not defined &Carp::caller_info ) {
+      ## no critic (RequireBarewordIncludes, ProhibitPunctuationVars )
+    require 'Carp/Heavy.pm' unless $^O eq 'MSWin32';
+    require 'Carp\Heavy.pm' if $^O eq 'MSWin32';
+    $callerinfo = \&Carp::Heavy::caller_info;
+  }
+  else {
+    $callerinfo = \&Carp::caller_info;
+  }
   {    # stolen parts  from Carp::ret_backtrace
     my ($i) = 0;
 
@@ -43,12 +54,12 @@ sub throw {
       $tid_msg = " thread $tid" if $tid;
     }
 
-    my %i = Carp::caller_info($i);
+    my %i = $callerinfo->($i);
 
     push @stack, \%i;
     push @stacklines, sprintf q{Exception '%s' thrown at %s line %s%s}, blessed($self), $i{file}, $i{line}, $tid_msg;
 
-    while ( my %j = Carp::caller_info( ++$i ) ) {
+    while ( my %j = $callerinfo->( ++$i ) ) {
       push @stack, \%j;
       push @stacklines, sprintf q{%s called at %s line %s%s}, $j{sub_name}, $j{file}, $j{line}, $tid_msg;
     }
@@ -116,9 +127,7 @@ sub _gen {
 sub _gen_tree {
   my ( $self, $class ) = @_;
   my $parent = $class;
-  require Carp;
 
-  #    Carp::carp("Generating $class.");
   $parent =~ s{
      ::[^:]+$
     }{}x;
@@ -147,7 +156,7 @@ Data::Handle::Exception - Super-light Weight Dependency Free Exception base.
 
 =head1 VERSION
 
-version 0.01011500
+version 0.01011501
 
 =head1 SYNOPSIS
 
